/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - AbstractJMXTableSupport.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.agent.mo.jmx;

import java.util.*;

import org.snmp4j.agent.mo.*;
import org.snmp4j.smi.*;
import org.snmp4j.PDU;
import javax.management.ObjectName;

public abstract class AbstractJMXTableSupport implements JMXTableSupport {

  protected Map<OID,JMXTableDetailSupport> columnValueMappings =
      new HashMap<OID,JMXTableDetailSupport>(10);

  public AbstractJMXTableSupport() {
  }

  public void add(OID tableOID,
                  JMXRowSupport rowSupport,
                  JMXColumnSupport columnSupport) {
    this.columnValueMappings.put(tableOID,
                                 new JMXTableDetailSupport(rowSupport,
        columnSupport));
  }

  public JMXTableDetailSupport removeDetailSupport(OID tableOID) {
    return this.removeDetailSupport(tableOID);
  }

  public abstract OID getLastIndex(OID tableOID);

  public int getRow(OID tableOID, MOTableRow row) {
    Object rowKey = mapToRowId(tableOID, row.getIndex());
    if (rowKey != null) {
      JMXTableDetailSupport detailSupport = getTableDetailSupport(tableOID);
      if (detailSupport != null) {
        ObjectName mBean =
            detailSupport.getRowSupport().getRowMBean(tableOID, rowKey);
        for (int i = 0; i < row.size(); i++) {
          Variable v = row.getValue(i);
          detailSupport.getColumnSupport().getColumnValue(mBean, i, v);
        }
      }
      return PDU.noError;
    }
    return PDU.resourceUnavailable;
  }

  protected synchronized JMXTableDetailSupport getTableDetailSupport(OID tableOID) {
    return columnValueMappings.get(tableOID);
  }

  public JMXRowSupport getRowSupport(OID tableOID) {
    JMXTableDetailSupport detailSupport = getTableDetailSupport(tableOID);
    if (detailSupport != null) {
      return detailSupport.getRowSupport();
    }
    return null;
  }

  public JMXColumnSupport getColumnSupport(OID tableOID) {
    JMXTableDetailSupport detailSupport = getTableDetailSupport(tableOID);
    if (detailSupport != null) {
      return detailSupport.getColumnSupport();
    }
    return null;
  }

  public abstract int getRowCount(OID tableOID);

  public abstract Iterator rowIdIterator(OID tableOID);

  public abstract OID mapToIndex(OID tableOID, Object rowIdentifier);

  public abstract Object mapToRowId(OID tableOID, OID rowIndex);

  class JMXTableDetailSupport {
    private JMXColumnSupport columnSupport;
    private JMXRowSupport rowSupport;

    public JMXTableDetailSupport(JMXRowSupport rowSupport,
                                 JMXColumnSupport columnSupport) {
      this.rowSupport = rowSupport;
      this.columnSupport = columnSupport;
    }

    public JMXRowSupport getRowSupport() {
      return rowSupport;
    }

    public JMXColumnSupport getColumnSupport() {
      return columnSupport;
    }

  }

}
