/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - JMXNotificationIndexSupport.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.agent.mo.jmx;

import org.snmp4j.smi.OID;

/**
 * Notification objects can refer to scalar and tabular data. Whereas for scalar
 * data the OID of the instance is constant, the index portion of the instance
 * identifier of tabular data may vary from notification to notification.
 * <p>
 * This interface provides the means needed by a {@link MBeanNotificationInfo}
 * instance to send a notification referring to tabular data.
 *
 * @author Frank Fock
 * @version 1.0
 */
public interface JMXNotificationIndexSupport {

  /**
   * Initialize the index support instance with the MBean notification object.
   * @param notificationUserObject
   *    an Object that contains or refers to the payload data of the
   *    notification.
   */
  void intialize(Object notificationUserObject);

  /**
   * Gets the index portion for the object with the specified index in the
   * notification.
   * @param objectIndex
   *    a zero based index into the SNMP notification objects.
   * @return OID
   *    a row index for the n-th notification object.
   */
  OID getIndex(int objectIndex);

}
