/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - Boolean2IntegerType.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.agent.mo.jmx.types;

import javax.management.*;

public class Boolean2IntegerType extends TypedAttribute {

  public static final int TRUTH_VALUE_FOR_TRUE = 1;
  public static final int TRUTH_VALUE_FOR_FALSE = 2;

  private Integer trueValue = new Integer(TRUTH_VALUE_FOR_TRUE);
  private Integer falseValue = new Integer(TRUTH_VALUE_FOR_FALSE);

  public Boolean2IntegerType(String name) {
    super(name, Integer.class);
  }

  public Boolean2IntegerType(String name,
                             Integer trueValue, Integer falseValue) {
    super(name, Integer.class);
    this.trueValue = trueValue;
    this.falseValue = falseValue;
  }

  public Object transformFromNative(Object nativeValue, ObjectName objectName) {
    boolean b = ((Boolean)nativeValue).booleanValue();
    return b ? trueValue : falseValue;
  }

  public Object transformToNative(Object transformedValue,
                                  Object oldNativeValue, ObjectName objectName) {
    if (transformedValue instanceof Integer) {
      if (transformedValue.equals(trueValue)) {
        return true;
      }
      else if (transformedValue.equals(falseValue)) {
        return false;
      }
    }
    return null;
  }
}
